<?php

/**
 * @file
 * Theme callback functions for "Save for later".
 */

/**
 * @see uc_save_for_later_saved_cart_form()
 */
function theme_uc_save_for_later_saved_cart_form($form) {
  drupal_add_css(drupal_get_path('module', 'uc_save_for_later') . '/uc_save_for_later.css');

  $output = '<h3 class="heading">' . drupal_render($form['heading']) . '</h3>';
  $output .= '<p class="description">' . drupal_render($form['description']) . '</p>';
  $output .= '<div id="save-for-later-cart-form-products">' . drupal_render($form) . '</div>';

  return $output;
}

/**
 * Theme the quantity value for saved carts.
 *
 * Renders qty values as plain text rather than a hidden form value.
 */
function theme_uc_save_for_later_disable_saved_qty($element) {
  return check_plain($element['#value']);
}

/**
 * Theme the cart when it is empty (no items).
 *
 * This override is needed as the default theme_uc_empty_cart() does not render
 * any cart panes if the cart is empty, however the saved cart may still contain
 * items. This override therefore renders cart panes even if the active cart is
 * empty.
 *
 * @see theme_uc_empty_cart()
 */
function theme_uc_save_for_later_empty_cart() {
  $output = '<p>' . t('There are no products in your shopping cart.') . '</p>';

  // Render cart panes, but not cart_form because there's no product in the
  // active cart.
  $panes = uc_cart_cart_pane_list(array());
  foreach ($panes as $pane) {
    if ($pane['enabled'] && $pane['id'] != 'cart_form') {
      $output .= $pane['body'];
    }
  }

  return $output;
}

/**
 * Theme the cart block summary to include the number of "Save for later" items.
 *
 * This is a copy of theme_uc_cart_block_summary() with modifications to output
 * a 'View cart' link if there are item(s) in the saved cart. A saved cart
 * summary is also added.
 *
 * @see theme_uc_cart_block_summary()
 */
function theme_uc_save_for_later_cart_block_summary($item_count, $item_text, $total, $summary_links) {
  $context = array(
    'revision' => 'themed-original',
    'type' => 'amount',
  );
  // Build the basic table with the number of items in the cart and total.
  $output = '<table class="cart-block-summary"><tbody><tr>'
           .'<td class="cart-block-summary-items">'. $item_text .'</td>'
           .'<td class="cart-block-summary-total"><label>'. t('Total:')
           .'</label> '. uc_price($total, $context) .'</td></tr>';

  // If there are items in the saved cart...
  if ($saved_count = count(uc_cart_get_contents(uc_save_for_later_get_cart_id()))) {
    // Add a summary count.
    $num_items = format_plural($saved_count, '<span class="num-items">@count</span> item Saved for later', '<span class="num-items">@count</span> items saved for later');
    $output .= '<tr class="uc-save-for-later-num-items"><td colspan="2">' . $num_items . '</td></tr>';
  }

  // If there are items in the active cart OR the active cart is empty with
  // items in the saved cart.
  if ($item_count > 0 || ($item_count == 0 && $saved_count > 0)) {
    // If there are no items in the active cart.
    if ($item_count == 0) {
      // Don't link to checkout.
      unset($summary_links['cart-block-checkout']);
    }
    // Add a view cart link.
    $output .= '<tr class="cart-block-summary-links"><td colspan="2">'
             . theme('links', $summary_links) .'</td></tr>';
  }

  $output .= '</tbody></table>';

  return $output;
}
